pub enum Ipv6OptionFailureAction {
Skip,
Discard,
DiscardSendError,
DiscardSendErrorIfUnicast,
}Expand description
The action required of a node that does not recognize an option, from the two highest-order bits of the option type (RFC 8200 4.2).
Variants
Skip
Skip the option and continue processing the header.
Discard
Discard the packet silently.
DiscardSendError
Discard the packet and send an ICMP Parameter Problem error.
DiscardSendErrorIfUnicast
Discard the packet and send an ICMP Parameter Problem error, but only if the packet’s destination was not a multicast address.