xarxa

Crates

git

Versions

default

Flavors

ArpPacket

Struct ArpPacket 

pub struct ArpPacket<'a> { /* private fields */ }
A read/write wrapper around an Address Resolution Protocol packet buffer.

Implementations

Source

impl<'a> Packet<'a>

pub const fn new_unchecked(buffer: &'a mut [u8]) -> Packet<'a>

Imbue a raw octet buffer with ARP packet structure.

pub fn new_checked(buffer: &'a mut [u8]) -> Result<Packet<'a>>

Shorthand for a combination of new_unchecked and check_len.

pub fn check_len(&self) -> Result<()>

Ensure that no accessor method will panic if called. Returns Err(Error) if the buffer is too short.

The result of this check is invalidated by calling set_hardware_len or set_protocol_len.

pub fn hardware_type(&self) -> Hardware

Return the hardware type field.

pub fn protocol_type(&self) -> Protocol

Return the protocol type field.

pub fn hardware_len(&self) -> u8

Return the hardware length field.

pub fn protocol_len(&self) -> u8

Return the protocol length field.

pub fn operation(&self) -> Operation

Return the operation field.

pub fn source_hardware_addr(&self) -> &[u8]

Return the source hardware address field.

pub fn source_protocol_addr(&self) -> &[u8]

Return the source protocol address field.

pub fn target_hardware_addr(&self) -> &[u8]

Return the target hardware address field.

pub fn target_protocol_addr(&self) -> &[u8]

Return the target protocol address field.

pub fn set_hardware_type(&mut self, value: Hardware)

Set the hardware type field.

pub fn set_protocol_type(&mut self, value: Protocol)

Set the protocol type field.

pub fn set_hardware_len(&mut self, value: u8)

Set the hardware length field.

pub fn set_protocol_len(&mut self, value: u8)

Set the protocol length field.

pub fn set_operation(&mut self, value: Operation)

Set the operation field.

pub fn set_source_hardware_addr(&mut self, value: &[u8])

Set the source hardware address field.

Panics

The function panics if value is not self.hardware_len() long.

pub fn set_source_protocol_addr(&mut self, value: &[u8])

Set the source protocol address field.

Panics

The function panics if value is not self.protocol_len() long.

pub fn set_target_hardware_addr(&mut self, value: &[u8])

Set the target hardware address field.

Panics

The function panics if value is not self.hardware_len() long.

pub fn set_target_protocol_addr(&mut self, value: &[u8])

Set the target protocol address field.

Panics

The function panics if value is not self.protocol_len() long.