xarxa

Crates

git

Versions

default

Flavors

DhcpOptionWriter

Struct DhcpOptionWriter 

pub struct DhcpOptionWriter<'a> { /* private fields */ }
Writes DHCP options into the options field of a packet, one after the other.

Returned by Packet::options_mut.

Implementations

Source

impl<'a> OptionWriter<'a>

pub fn new(buffer: &'a mut [u8]) -> Self

Start writing options at the beginning of buffer.

pub fn emit(&mut self, option: DhcpOption<'_>) -> Result<()>

Write one option.

Errors if the option data is longer than 255 bytes or doesn’t fit in the remaining space.

pub fn end(&mut self) -> Result<()>

Write the end marker. No more options can be written after this.

Errors if there is no space left.

pub fn written(&self) -> usize

How many bytes have been written so far, the end marker included.