xarxa

Crates

git

Versions

default

Flavors

DnsPacket

Struct DnsPacket 

pub struct DnsPacket<'a> { /* private fields */ }
A read/write wrapper around a DNS packet buffer.

Implementations

Source

impl<'a> Packet<'a>

pub const fn new_unchecked(buffer: &'a mut [u8]) -> Packet<'a>

Imbue a raw octet buffer with DNS packet structure.

pub fn new_checked(buffer: &'a mut [u8]) -> Result<Packet<'a>>

Shorthand for a combination of new_unchecked and check_len.

pub fn check_len(&self) -> Result<()>

Ensure that no accessor method will panic if called. Returns Err(Error) if the buffer is smaller than the header length.

pub fn into_inner(self) -> &'a mut [u8]

Consume the packet, returning the underlying buffer.

pub fn payload(&self) -> &[u8]

The bytes after the header: questions and records.

pub fn transaction_id(&self) -> u16

Return the transaction ID field.

pub fn flags(&self) -> Flags

Return the flags field.

pub fn opcode(&self) -> Opcode

Return the opcode field.

pub fn rcode(&self) -> Rcode

Return the response code field.

pub fn question_count(&self) -> u16

Return the question count field.

pub fn answer_record_count(&self) -> u16

Return the answer record count field.

pub fn authority_record_count(&self) -> u16

Return the authority record count field.

pub fn additional_record_count(&self) -> u16

Return the additional record count field.

pub fn parse_name<'b>( &'b self, bytes: &'b [u8], ) -> impl Iterator<Item = Result<&'b [u8]>>

Parse a name from bytes, following compression pointers into this packet.

Yields one label at a time. Pointers are only allowed to point backwards, so pointer loops end the iteration with an error.

pub fn payload_mut(&mut self) -> &mut [u8]

The bytes after the header, mutable.

pub fn set_transaction_id(&mut self, val: u16)

Set the transaction ID field.

pub fn set_flags(&mut self, val: Flags)

Set the flags field. Leaves the opcode and rcode bits alone.

pub fn set_opcode(&mut self, val: Opcode)

Set the opcode field.

pub fn set_question_count(&mut self, val: u16)

Set the question count field.

pub fn set_answer_record_count(&mut self, val: u16)

Set the answer record count field.

pub fn set_authority_record_count(&mut self, val: u16)

Set the authority record count field.

pub fn set_additional_record_count(&mut self, val: u16)

Set the additional record count field.