xarxa

Crates

git

Versions

default

Flavors

EthernetFrame

Struct EthernetFrame 

pub struct EthernetFrame<'a> { /* private fields */ }
A read/write wrapper around an Ethernet II frame buffer.

Implementations

Source

impl<'a> Frame<'a>

pub const fn new_unchecked(buffer: &'a mut [u8]) -> Frame<'a>

Imbue a raw octet buffer with Ethernet frame structure.

pub fn new_checked(buffer: &'a mut [u8]) -> Result<Frame<'a>>

Shorthand for a combination of new_unchecked and check_len.

pub fn check_len(&self) -> Result<()>

Ensure that no accessor method will panic if called. Returns Err(Error) if the buffer is too short.

pub const fn header_len() -> usize

Return the length of a frame header.

pub const fn buffer_len(payload_len: usize) -> usize

Return the length of a buffer required to hold a packet with the payload of a given length.

pub fn dst_addr(&self) -> Address

Return the destination address field.

pub fn src_addr(&self) -> Address

Return the source address field.

pub fn ethertype(&self) -> EtherType

Return the EtherType field, without checking for 802.1Q.

pub fn payload(&self) -> &[u8]

Return a pointer to the payload, without checking for 802.1Q.

pub fn set_dst_addr(&mut self, value: Address)

Set the destination address field.

pub fn set_src_addr(&mut self, value: Address)

Set the source address field.

pub fn set_ethertype(&mut self, value: EtherType)

Set the EtherType field.

pub fn payload_mut(&mut self) -> &mut [u8]

Return a mutable pointer to the payload.