xarxa

Crates

git

Versions

default

Flavors

Icmpv4Packet

Struct Icmpv4Packet 

pub struct Icmpv4Packet<'a> { /* private fields */ }
A read/write wrapper around an Internet Control Message Protocol version 4 packet buffer.

Implementations

Source

impl<'a> Packet<'a>

pub const fn new_unchecked(buffer: &'a mut [u8]) -> Packet<'a>

Imbue a raw octet buffer with ICMPv4 packet structure.

pub fn new_checked(buffer: &'a mut [u8]) -> Result<Packet<'a>>

Shorthand for a combination of new_unchecked and check_len.

pub fn check_len(&self) -> Result<()>

Ensure that no accessor method will panic if called. Returns Err(Error) if the buffer is too short.

The result of this check is invalidated by calling set_header_len.

pub fn msg_type(&self) -> Message

Return the message type field.

pub fn msg_code(&self) -> u8

Return the message code field.

pub fn checksum(&self) -> u16

Return the checksum field.

pub fn echo_ident(&self) -> u16

Return the identifier field (for echo request and reply packets).

Panics

This function may panic if this packet is not an echo request or reply packet.

pub fn echo_seq_no(&self) -> u16

Return the sequence number field (for echo request and reply packets).

Panics

This function may panic if this packet is not an echo request or reply packet.

pub fn header_len(&self) -> usize

Return the header length. The result depends on the value of the message type field.

pub fn verify_checksum(&self) -> bool

Validate the header checksum.

Fuzzing

This function always returns true when fuzzing.

pub fn data(&self) -> &[u8]

Return a pointer to the type-specific data.

pub fn set_msg_type(&mut self, value: Message)

Set the message type field.

pub fn set_msg_code(&mut self, value: u8)

Set the message code field.

pub fn set_checksum(&mut self, value: u16)

Set the checksum field.

pub fn set_echo_ident(&mut self, value: u16)

Set the identifier field (for echo request and reply packets).

Panics

This function may panic if this packet is not an echo request or reply packet.

pub fn set_echo_seq_no(&mut self, value: u16)

Set the sequence number field (for echo request and reply packets).

Panics

This function may panic if this packet is not an echo request or reply packet.

pub fn clear_unused(&mut self)

Zero the unused field of an error message (destination unreachable, time exceeded) header.

pub fn fill_checksum(&mut self)

Compute and fill in the header checksum.

pub fn data_mut(&mut self) -> &mut [u8]

Return a mutable pointer to the type-specific data.