pub struct Icmpv6Message(pub u8);Expand description
Internet protocol control message type.
Tuple Fields
0: u8Implementations
Sourceimpl Message
impl Message
Sourcepub const DstUnreachable: Self
pub const DstUnreachable: Self
Destination Unreachable.
Sourcepub const TimeExceeded: Self
pub const TimeExceeded: Self
Time Exceeded.
Sourcepub const ParamProblem: Self
pub const ParamProblem: Self
Parameter Problem.
Sourcepub const EchoRequest: Self
pub const EchoRequest: Self
Echo Request
Sourcepub const RouterSolicit: Self
pub const RouterSolicit: Self
Router Solicitation
Sourcepub const RouterAdvert: Self
pub const RouterAdvert: Self
Router Advertisement
Sourcepub const NeighborSolicit: Self
pub const NeighborSolicit: Self
Neighbor Solicitation
Sourcepub const NeighborAdvert: Self
pub const NeighborAdvert: Self
Neighbor Advertisement
Sourcepub const RplControl: Self
pub const RplControl: Self
RPL Control Message
Sourceimpl Message
impl Message
Sourcepub fn is_error(&self) -> bool
pub fn is_error(&self) -> bool
Per RFC 4443  2.1 ICMPv6 message types with the highest order bit set are informational messages while message types without the highest order bit set are error messages.