xarxa

Crates

git

Versions

default

Flavors

IgmpPacket

Struct IgmpPacket 

pub struct IgmpPacket<'a> { /* private fields */ }
A read/write wrapper around an Internet Group Management Protocol v1/v2 packet buffer.

Implementations

Source

impl<'a> Packet<'a>

Internet Group Management Protocol v1/v2 defined in RFC 2236.

pub const fn new_unchecked(buffer: &'a mut [u8]) -> Packet<'a>

Imbue a raw octet buffer with IGMPv2 packet structure.

pub fn new_checked(buffer: &'a mut [u8]) -> Result<Packet<'a>>

Shorthand for a combination of new_unchecked and check_len.

pub fn check_len(&self) -> Result<()>

Ensure that no accessor method will panic if called. Returns Err(Error) if the buffer is too short.

pub fn msg_type(&self) -> Message

Return the message type field.

pub fn max_resp_code(&self) -> u8

Return the maximum response time, using the encoding specified in RFC 3376: 4.1.1. Max Resp Code.

pub fn max_resp_time(&self) -> Duration

Return the maximum response time, decoded from the max resp code field.

pub fn checksum(&self) -> u16

Return the checksum field.

pub fn group_addr(&self) -> Ipv4Address

Return the group address field.

pub fn verify_checksum(&self) -> bool

Validate the header checksum.

Fuzzing

This function always returns true when fuzzing.

pub fn set_msg_type(&mut self, value: Message)

Set the message type field.

pub fn set_max_resp_code(&mut self, value: u8)

Set the maximum response time, using the encoding specified in RFC 3376: 4.1.1. Max Resp Code.

pub fn set_max_resp_time(&mut self, value: Duration)

Set the maximum response time, encoding it into the max resp code field.

pub fn set_checksum(&mut self, value: u16)

Set the checksum field.

pub fn set_group_address(&mut self, addr: Ipv4Address)

Set the group address field

pub fn fill_checksum(&mut self)

Compute and fill in the header checksum.