xarxa

Crates

git

Versions

default

Flavors

Ipv4Packet

Struct Ipv4Packet 

pub struct Ipv4Packet<'a> { /* private fields */ }
A read/write wrapper around an Internet Protocol version 4 packet buffer.

Implementations

Source

impl<'a> Packet<'a>

pub const fn new_unchecked(buffer: &'a mut [u8]) -> Packet<'a>

Imbue a raw octet buffer with IPv4 packet structure.

pub fn new_checked(buffer: &'a mut [u8]) -> Result<Packet<'a>>

Shorthand for a combination of new_unchecked and check_len.

pub fn check_len(&self) -> Result<()>

Ensure that no accessor method will panic if called. Returns Err(Error) if the buffer is too short. Returns Err(Error) if the header length is greater than total length. Returns Err(Error) if the header length is less than minimum allowed IHL

The result of this check is invalidated by calling set_header_len and set_total_len.

pub fn version(&self) -> u8

Return the version field.

pub fn header_len(&self) -> u8

Return the header length, in octets.

pub fn dscp(&self) -> u8

Return the Differential Services Code Point field.

pub fn ecn(&self) -> u8

Return the Explicit Congestion Notification field.

pub fn total_len(&self) -> u16

Return the total length field.

pub fn ident(&self) -> u16

Return the fragment identification field.

pub fn dont_frag(&self) -> bool

Return the “don’t fragment” flag.

pub fn more_frags(&self) -> bool

Return the “more fragments” flag.

pub fn frag_offset(&self) -> u16

Return the fragment offset, in octets.

pub fn hop_limit(&self) -> u8

Return the time to live field.

pub fn next_header(&self) -> Protocol

Return the next_header (protocol) field.

pub fn checksum(&self) -> u16

Return the header checksum field.

pub fn src_addr(&self) -> Address

Return the source address field.

pub fn dst_addr(&self) -> Address

Return the destination address field.

pub fn verify_checksum(&self) -> bool

Validate the header checksum.

Fuzzing

This function always returns true when fuzzing.

pub fn payload(&self) -> &[u8]

Return a pointer to the payload.

pub fn set_version(&mut self, value: u8)

Set the version field.

pub fn set_header_len(&mut self, value: u8)

Set the header length, in octets.

pub fn set_dscp(&mut self, value: u8)

Set the Differential Services Code Point field.

pub fn set_ecn(&mut self, value: u8)

Set the Explicit Congestion Notification field.

pub fn set_total_len(&mut self, value: u16)

Set the total length field.

pub fn set_ident(&mut self, value: u16)

Set the fragment identification field.

pub fn clear_flags(&mut self)

Clear the entire flags field.

pub fn set_dont_frag(&mut self, value: bool)

Set the “don’t fragment” flag.

pub fn set_more_frags(&mut self, value: bool)

Set the “more fragments” flag.

pub fn set_frag_offset(&mut self, value: u16)

Set the fragment offset, in octets.

pub fn set_hop_limit(&mut self, value: u8)

Set the time to live field.

pub fn set_next_header(&mut self, value: Protocol)

Set the next header (protocol) field.

pub fn set_checksum(&mut self, value: u16)

Set the header checksum field.

pub fn set_src_addr(&mut self, value: Address)

Set the source address field.

pub fn set_dst_addr(&mut self, value: Address)

Set the destination address field.

pub fn fill_checksum(&mut self)

Compute and fill in the header checksum.

pub fn payload_mut(&mut self) -> &mut [u8]

Return a mutable pointer to the payload.