xarxa

Crates

git

Versions

default

Flavors

MldAddressRecord

Struct MldAddressRecord 

pub struct MldAddressRecord<'a> { /* private fields */ }
A read/write wrapper around an MLDv2 Listener Report Message Address Record.

Implementations

Source

impl<'a> AddressRecord<'a>

pub const fn new_unchecked(buffer: &'a mut [u8]) -> Self

Imbue a raw octet buffer with a Address Record structure.

pub fn new_checked(buffer: &'a mut [u8]) -> Result<Self>

Shorthand for a combination of new_unchecked and check_len.

pub fn check_len(&self) -> Result<()>

Ensure that no accessor method will panic if called. Returns Err(Error) if the buffer is too short.

Source

impl<'a> AddressRecord<'a>

Getters for a MLDv2 Listener Report Message Address Record. See RFC 3810  5.2.

pub fn record_type(&self) -> RecordType

Return the record type for the given sources.

pub fn aux_data_len(&self) -> u8

Return the length of the auxiliary data.

pub fn num_srcs(&self) -> u16

Return the number of sources field.

pub fn mcast_addr(&self) -> Ipv6Address

Return the multicast address field.

pub fn payload(&self) -> &[u8]

Return a pointer to the address records.

Source

impl<'a> AddressRecord<'a>

Setters for a MLDv2 Listener Report Message Address Record. See RFC 3810  5.2.

pub fn set_record_type(&mut self, rty: RecordType)

Set the record type for the given sources.

pub fn set_aux_data_len(&mut self, len: u8)

Set the length of the auxiliary data.

pub fn set_num_srcs(&mut self, num_srcs: u16)

Set the number of sources field.

pub fn set_mcast_addr(&mut self, addr: Ipv6Address)

Set the multicast address field.

Panics

This function panics if the given address is not a multicast address.

pub fn payload_mut(&mut self) -> &mut [u8]

Return a mutable pointer to the address records.