pub struct MldRecordType(pub u8);Expand description
MLDv2 Multicast Listener Report Record Type. See RFC 3810  5.2.12 for more details.
Tuple Fields
0: u8Implementations
Sourceimpl RecordType
impl RecordType
Sourcepub const ModeIsInclude: Self
pub const ModeIsInclude: Self
Interface has a filter mode of INCLUDE for the specified multicast address.
Sourcepub const ModeIsExclude: Self
pub const ModeIsExclude: Self
Interface has a filter mode of EXCLUDE for the specified multicast address.
Sourcepub const ChangeToInclude: Self
pub const ChangeToInclude: Self
Interface has changed to a filter mode of INCLUDE for the specified multicast address.
Sourcepub const ChangeToExclude: Self
pub const ChangeToExclude: Self
Interface has changed to a filter mode of EXCLUDE for the specified multicast address.
Sourcepub const AllowNewSources: Self
pub const AllowNewSources: Self
Interface wishes to listen to the sources in the specified list.
Sourcepub const BlockOldSources: Self
pub const BlockOldSources: Self
Interface no longer wishes to listen to the sources in the specified list.