xarxa

Crates

git

Versions

default

Flavors

NdiscOption

Struct NdiscOption 

pub struct NdiscOption<'a> { /* private fields */ }
A read/write wrapper around an NDISC Option.

Implementations

Source

impl<'a> NdiscOption<'a>

Core getter methods relevant to any type of NDISC option.

pub const fn new_unchecked(buffer: &'a mut [u8]) -> NdiscOption<'a>

Create a raw octet buffer with an NDISC Option structure.

pub fn new_checked(buffer: &'a mut [u8]) -> Result<NdiscOption<'a>>

Shorthand for a combination of new_unchecked and check_len.

pub fn check_len(&self) -> Result<()>

Ensure that no accessor method will panic if called. Returns Err(Error) if the buffer is too short.

The result of this check is invalidated by calling set_data_len.

pub fn option_type(&self) -> Type

Return the option type.

pub fn data_len(&self) -> u8

Return the length of the data.

Source

impl<'a> NdiscOption<'a>

Getter methods only relevant for Source/Target Link-layer Address options.

Return the Source/Target Link-layer Address.

Source

impl<'a> NdiscOption<'a>

Getter methods only relevant for the MTU option.

pub fn mtu(&self) -> u32

Return the MTU value.

Source

impl<'a> NdiscOption<'a>

Getter methods only relevant for the Prefix Information option.

pub fn prefix_len(&self) -> u8

Return the prefix length.

pub fn prefix_flags(&self) -> PrefixInfoFlags

Return the prefix information flags.

pub fn valid_lifetime(&self) -> Duration

Return the valid lifetime of the prefix.

pub fn preferred_lifetime(&self) -> Duration

Return the preferred lifetime of the prefix.

pub fn prefix(&self) -> Ipv6Address

Return the prefix.

Source

impl<'a> NdiscOption<'a>

pub fn data(&self) -> &[u8]

Return the option data.

Source

impl<'a> NdiscOption<'a>

Core setter methods relevant to any type of NDISC option.

pub fn set_option_type(&mut self, value: Type)

Set the option type.

pub fn set_data_len(&mut self, value: u8)

Set the option data length.

Source

impl<'a> NdiscOption<'a>

Setter methods only relevant for Source/Target Link-layer Address options.

Set the Source/Target Link-layer Address.

Source

impl<'a> NdiscOption<'a>

Setter methods only relevant for the MTU option.

pub fn set_mtu(&mut self, value: u32)

Set the MTU value.

Source

impl<'a> NdiscOption<'a>

Setter methods only relevant for the Prefix Information option.

pub fn set_prefix_len(&mut self, value: u8)

Set the prefix length.

pub fn set_prefix_flags(&mut self, flags: PrefixInfoFlags)

Set the prefix information flags.

pub fn set_valid_lifetime(&mut self, time: Duration)

Set the valid lifetime of the prefix.

pub fn set_preferred_lifetime(&mut self, time: Duration)

Set the preferred lifetime of the prefix.

pub fn clear_prefix_reserved(&mut self)

Clear the reserved bits.

pub fn set_prefix(&mut self, addr: Ipv6Address)

Set the prefix.

Source

impl<'a> NdiscOption<'a>

Setter methods only relevant for the Redirected Header option.

pub fn clear_redirected_reserved(&mut self)

Clear the reserved bits.

Source

impl<'a> NdiscOption<'a>

pub fn data_mut(&mut self) -> &mut [u8]

Return a mutable pointer to the option data.