pub struct RawHardwareAddress { /* private fields */ }Expand description
Unparsed hardware address.
Used to make NDISC parsing agnostic of the hardware medium in use.
Implementations
Sourceimpl RawHardwareAddress
impl RawHardwareAddress
Sourcepub fn from_bytes(addr: &[u8]) -> Self
pub fn from_bytes(addr: &[u8]) -> Self
Create a new RawHardwareAddress from a byte slice.
Panics
Panics if addr.len() > MAX_HARDWARE_ADDRESS_LEN.
pub fn as_bytes(&self) -> &[u8] ⓘ
pub const fn len(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn parse(&self, medium: Medium) -> Result<HardwareAddress>
pub fn parse(&self, medium: Medium) -> Result<HardwareAddress>
Parse the address as an address of the given medium.
Errors:
Errorif the length is wrong for the medium: 6 bytes for Ethernet, 8 (an extended address) for IEEE 802.15.4, or if the medium has no addresses.