pub struct DhcpOptionWriter<'a> { /* private fields */ }Expand description
Writes DHCP options into the options field of a packet, one after the other.
Returned by Packet::options_mut.
Implementations
Sourceimpl<'a> OptionWriter<'a>
impl<'a> OptionWriter<'a>
Sourcepub fn emit(&mut self, option: DhcpOption<'_>) -> Result<()>
pub fn emit(&mut self, option: DhcpOption<'_>) -> Result<()>
Write one option.
Errors if the option data is longer than 255 bytes or doesn’t fit in the remaining space.