pub struct DhcpPacket<'a> { /* private fields */ }Expand description
A read/write wrapper around a Dynamic Host Configuration Protocol packet buffer.
Implementations
Sourceimpl<'a> Packet<'a>
impl<'a> Packet<'a>
Sourcepub const fn new_unchecked(buffer: &'a mut [u8]) -> Packet<'a>
pub const fn new_unchecked(buffer: &'a mut [u8]) -> Packet<'a>
Imbue a raw octet buffer with DHCP packet structure.
Sourcepub fn new_checked(buffer: &'a mut [u8]) -> Result<Packet<'a>>
pub fn new_checked(buffer: &'a mut [u8]) -> Result<Packet<'a>>
Shorthand for a combination of new_unchecked and check_len.
Sourcepub fn check_len(&self) -> Result<()>
pub fn check_len(&self) -> Result<()>
Ensure that no accessor method will panic if called.
Returns Err(Error) if the buffer is too short.
Sourcepub fn hardware_type(&self) -> Hardware
pub fn hardware_type(&self) -> Hardware
Return the hardware protocol type (e.g. ethernet).
Sourcepub fn hardware_len(&self) -> u8
pub fn hardware_len(&self) -> u8
Return the length of a hardware address in bytes (e.g. 6 for ethernet).
Sourcepub fn transaction_id(&self) -> u32
pub fn transaction_id(&self) -> u32
Return the transaction ID.
The transaction ID (called xid in the specification) is a random number used to
associate messages and responses between client and server. The number is chosen by
the client.
Sourcepub fn client_hardware_address(&self) -> EthernetAddress
pub fn client_hardware_address(&self) -> EthernetAddress
Return the hardware address of the client (called chaddr in the specification).
Only ethernet is supported, so this returns an EthernetAddress.
Sourcepub fn hops(&self) -> u8
pub fn hops(&self) -> u8
Return the value of the hops field.
The hops field is set to zero by clients and optionally used by relay agents.
Sourcepub fn secs(&self) -> u16
pub fn secs(&self) -> u16
Return the value of the secs field.
The secs field is filled by clients and describes the number of seconds elapsed since client began process.
Sourcepub fn magic_number(&self) -> u32
pub fn magic_number(&self) -> u32
Return the value of the magic cookie field in the DHCP options.
This field should be always be 0x63825363.
Sourcepub fn client_ip(&self) -> Ipv4Address
pub fn client_ip(&self) -> Ipv4Address
Return the Ipv4 address of the client, zero if not set.
This corresponds to the ciaddr field in the DHCP specification. According to it,
this field is “only filled in if client is in BOUND, RENEW or REBINDING state
and can respond to ARP requests”.
Sourcepub fn your_ip(&self) -> Ipv4Address
pub fn your_ip(&self) -> Ipv4Address
Return the value of the yiaddr field, zero if not set.
Sourcepub fn server_ip(&self) -> Ipv4Address
pub fn server_ip(&self) -> Ipv4Address
Return the value of the siaddr field, zero if not set.
Sourcepub fn relay_agent_ip(&self) -> Ipv4Address
pub fn relay_agent_ip(&self) -> Ipv4Address
Return the value of the giaddr field, zero if not set.
Sourcepub fn options(&self) -> impl Iterator<Item = DhcpOption<'_>> + '_
pub fn options(&self) -> impl Iterator<Item = DhcpOption<'_>> + '_
Return an iterator over the options.
Iteration stops at the end marker, at the end of the buffer, or at the first malformed option.
Sourcepub fn option(&self, kind: u8) -> Option<&[u8]>
pub fn option(&self, kind: u8) -> Option<&[u8]>
Return the data of the first option of the given kind, if present.
Sourcepub fn message_type(&self) -> Result<MessageType>
pub fn message_type(&self) -> Result<MessageType>
Return the message type, from the message type option.
Errors if the option is missing or malformed.
Sourcepub fn get_sname(&self) -> Result<&str>
pub fn get_sname(&self) -> Result<&str>
Return the sname (server name) field as a string.
Errors if it is empty or not valid UTF-8.
Sourcepub fn get_boot_file(&self) -> Result<&str>
pub fn get_boot_file(&self) -> Result<&str>
Return the file (boot file name) field as a string.
Errors if it is empty or not valid UTF-8.
Sourcepub fn set_sname_and_boot_file_to_zero(&mut self)
pub fn set_sname_and_boot_file_to_zero(&mut self)
Set the optional sname (“server name”) and file (“boot file name”) fields to zero.
The fields are not commonly used, so we set their value always to zero. This method must be called when creating a packet, otherwise the emitted values for these fields are undefined!
Sourcepub fn set_opcode(&mut self, value: OpCode)
pub fn set_opcode(&mut self, value: OpCode)
Set the OpCode for the packet.
Sourcepub fn set_hardware_type(&mut self, value: Hardware)
pub fn set_hardware_type(&mut self, value: Hardware)
Set the hardware address type (only ethernet is supported).
Sourcepub fn set_hardware_len(&mut self, value: u8)
pub fn set_hardware_len(&mut self, value: u8)
Set the hardware address length.
Only ethernet is supported, so this field should be set to the value 6.
Sourcepub fn set_transaction_id(&mut self, value: u32)
pub fn set_transaction_id(&mut self, value: u32)
Set the transaction ID.
The transaction ID (called xid in the specification) is a random number used to
associate messages and responses between client and server. The number is chosen by
the client.
Sourcepub fn set_client_hardware_address(&mut self, value: EthernetAddress)
pub fn set_client_hardware_address(&mut self, value: EthernetAddress)
Set the ethernet address of the client.
Sets the chaddr field.
Sourcepub fn set_hops(&mut self, value: u8)
pub fn set_hops(&mut self, value: u8)
Set the hops field.
The hops field is set to zero by clients and optionally used by relay agents.
Sourcepub fn set_secs(&mut self, value: u16)
pub fn set_secs(&mut self, value: u16)
Set the secs field.
The secs field is filled by clients and describes the number of seconds elapsed since client began process.
Sourcepub fn set_magic_number(&mut self, value: u32)
pub fn set_magic_number(&mut self, value: u32)
Set the value of the magic cookie field in the DHCP options.
This field should be always be 0x63825363.
Sourcepub fn set_client_ip(&mut self, value: Ipv4Address)
pub fn set_client_ip(&mut self, value: Ipv4Address)
Set the Ipv4 address of the client.
This corresponds to the ciaddr field in the DHCP specification. According to it,
this field is “only filled in if client is in BOUND, RENEW or REBINDING state
and can respond to ARP requests”.
Sourcepub fn set_your_ip(&mut self, value: Ipv4Address)
pub fn set_your_ip(&mut self, value: Ipv4Address)
Set the value of the yiaddr field.
Sourcepub fn set_server_ip(&mut self, value: Ipv4Address)
pub fn set_server_ip(&mut self, value: Ipv4Address)
Set the value of the siaddr field.
Sourcepub fn set_relay_agent_ip(&mut self, value: Ipv4Address)
pub fn set_relay_agent_ip(&mut self, value: Ipv4Address)
Set the value of the giaddr field.
Sourcepub fn options_mut(&mut self) -> OptionWriter<'_>
pub fn options_mut(&mut self) -> OptionWriter<'_>
Return a writer for the options field.
Sourcepub fn fill_client_header(
&mut self,
message_type: MessageType,
client_hardware_address: EthernetAddress,
)
pub fn fill_client_header( &mut self, message_type: MessageType, client_hardware_address: EthernetAddress, )
Fill in the fixed part of a client message: opcode, Ethernet hardware type and
length, zero hops and secs, zero sname and file, and the magic cookie.
The addresses, flags, transaction ID and options are left for the caller.